@@ -13,7 +13,7 @@ has foo => (
 );
 
 sub cli_options {
-    return qw(foo=s);
+    return qw(foo=s foobar=s);
 }
 
 sub run {
@@ -21,6 +21,10 @@ sub run {
     if ($self->has_foo) {
         return sprintf("You called me with foo=%s", $self->foo);
     }
+    elsif ($self->_cli_args->{foobar}) {
+        return
+          sprintf("You called me with foobar=%s", $self->_cli_args->{foobar});
+    }
     else {
         return "Called me with no args";
     }
